from setuptools import setup

setup(name='prob_d',
      version='0.1',
      description='Binomial distributions and Gaussian distributions',
      packages=['prob_d'],
      author='Nishita Jain',
      zip_safe=False)
